Available on crate feature postgres only.

Structs

CompositeType
A PostgreSQL composite type. Fields of a type can be accessed using CompositeType::get and CompositeType::try_get methods.
CompositeTypeRanges
A fallible iterator over the fields of a composite type.

Enums

Error

Type Aliases

Result