pub fn rows_to_arrow(
rows: Rows<'_>,
num_cols: usize,
projected_schema: Option<SchemaRef>,
) -> Result<RecordBatch>Available on crate feature
sqlite only.Expand description
Converts Sqlite Rows to an Arrow RecordBatch. Assumes that all rows have the same schema and
sets the schema based on the first row.
Errors
Returns an error if there is a failure in converting the rows to a RecordBatch.