pub struct SQLiteIntervalVisitor {}Available on crate features
sqlite and sqlite-federation only.Trait Implementations
Sourceimpl Default for SQLiteIntervalVisitor
impl Default for SQLiteIntervalVisitor
Sourcefn default() -> SQLiteIntervalVisitor
fn default() -> SQLiteIntervalVisitor
Returns the “default value” for a type. Read more
Sourceimpl VisitorMut for SQLiteIntervalVisitor
impl VisitorMut for SQLiteIntervalVisitor
Sourcefn pre_visit_expr(&mut self, expr: &mut Expr) -> ControlFlow<Self::Break>
fn pre_visit_expr(&mut self, expr: &mut Expr) -> ControlFlow<Self::Break>
Invoked for any expressions that appear in the AST before visiting children
Sourcefn pre_visit_query(&mut self, _query: &mut Query) -> ControlFlow<Self::Break>
fn pre_visit_query(&mut self, _query: &mut Query) -> ControlFlow<Self::Break>
Invoked for any queries that appear in the AST before visiting children
Sourcefn post_visit_query(&mut self, _query: &mut Query) -> ControlFlow<Self::Break>
fn post_visit_query(&mut self, _query: &mut Query) -> ControlFlow<Self::Break>
Invoked for any queries that appear in the AST after visiting children
Sourcefn pre_visit_relation(
&mut self,
_relation: &mut ObjectName,
) -> ControlFlow<Self::Break>
fn pre_visit_relation( &mut self, _relation: &mut ObjectName, ) -> ControlFlow<Self::Break>
Invoked for any relations (e.g. tables) that appear in the AST before visiting children
Sourcefn post_visit_relation(
&mut self,
_relation: &mut ObjectName,
) -> ControlFlow<Self::Break>
fn post_visit_relation( &mut self, _relation: &mut ObjectName, ) -> ControlFlow<Self::Break>
Invoked for any relations (e.g. tables) that appear in the AST after visiting children
Sourcefn pre_visit_table_factor(
&mut self,
_table_factor: &mut TableFactor,
) -> ControlFlow<Self::Break>
fn pre_visit_table_factor( &mut self, _table_factor: &mut TableFactor, ) -> ControlFlow<Self::Break>
Invoked for any table factors that appear in the AST before visiting children
Sourcefn post_visit_table_factor(
&mut self,
_table_factor: &mut TableFactor,
) -> ControlFlow<Self::Break>
fn post_visit_table_factor( &mut self, _table_factor: &mut TableFactor, ) -> ControlFlow<Self::Break>
Invoked for any table factors that appear in the AST after visiting children
Sourcefn post_visit_expr(&mut self, _expr: &mut Expr) -> ControlFlow<Self::Break>
fn post_visit_expr(&mut self, _expr: &mut Expr) -> ControlFlow<Self::Break>
Invoked for any expressions that appear in the AST
Sourcefn pre_visit_statement(
&mut self,
_statement: &mut Statement,
) -> ControlFlow<Self::Break>
fn pre_visit_statement( &mut self, _statement: &mut Statement, ) -> ControlFlow<Self::Break>
Invoked for any statements that appear in the AST before visiting children
Sourcefn post_visit_statement(
&mut self,
_statement: &mut Statement,
) -> ControlFlow<Self::Break>
fn post_visit_statement( &mut self, _statement: &mut Statement, ) -> ControlFlow<Self::Break>
Invoked for any statements that appear in the AST after visiting children
Sourcefn pre_visit_value(&mut self, _value: &mut Value) -> ControlFlow<Self::Break>
fn pre_visit_value(&mut self, _value: &mut Value) -> ControlFlow<Self::Break>
Invoked for any value that appear in the AST before visiting children
Sourcefn post_visit_value(&mut self, _value: &mut Value) -> ControlFlow<Self::Break>
fn post_visit_value(&mut self, _value: &mut Value) -> ControlFlow<Self::Break>
Invoked for any statements that appear in the AST after visiting children